==> 3.2.tar.gz: cosmopolitan/test/tool/viz/lib/halfblit_test.c <==
/*-*- mode:c;indent-tabs-mode:nil;c-basic-offset:2;tab-width:8;coding:utf-8 -*-│
│ vi: set et ft=c ts=2 sts=2 sw=2 fenc=utf-8                               :vi │
╞══════════════════════════════════════════════════════════════════════════════╡
│ Copyright 2020 Justine Alexandra Roberts Tunney                              │
│                                                                              │
│ Permission to use, copy, modify, and/or distribute this software for         │
│ any purpose with or without fee is hereby granted, provided that the         │
│ above copyright notice and this permission notice appear in all copies.      │
│                                                                              │
│ THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL                │
│ WARRANTIES WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED                │
│ WARRANTIES OF MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE             │
│ AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL         │
│ DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR        │
│ PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER               │
│ TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR             │
│ PERFORMANCE OF THIS SOFTWARE.                                                │
╚─────────────────────────────────────────────────────────────────────────────*/
#include "libc/fmt/bing.internal.h"
#include "libc/mem/gc.internal.h"
#include "libc/testlib/testlib.h"
#include "libc/x/x.h"
#include "tool/viz/lib/halfblit.h"

TEST(halfblit, test_4x4_to_2x2) {
  EXPECT_BINEQ(u" ☺"
               u"►◄",
               halfblit(2, gc(xunbing(u" ☺☻♥"
                                      u"►◄↕‼"
                                      u"♀♪♫☼"
                                      u"∟↔▲▼"))));
}

TEST(halfblit, test_8x8_to_4x4) {
  EXPECT_BINEQ(u" ☺☻♥"
               u"►◄↕‼"
               u"◘○◙♂"
               u"↑↓→←",
               halfblit(4, gc(xunbing(u" ☺☻♥♦♣♠•"
                                      u"►◄↕‼¶§▬↨"
                                      u"◘○◙♂♀♪♫☼"
                                      u"↑↓→←∟↔▲▼"
                                      u"01234567"
                                      u"░▒▓│┤╡╢╖"
                                      u"╕╣║╗╝╜╛┐"
                                      u"89:;<=>?"))));
}

==> 3.3.3.tar.gz: cosmopolitan/test/tool/viz/lib/halfblit_test.c <==
/*-*- mode:c;indent-tabs-mode:nil;c-basic-offset:2;tab-width:8;coding:utf-8 -*-│
│ vi: set et ft=c ts=2 sts=2 sw=2 fenc=utf-8                               :vi │
╞══════════════════════════════════════════════════════════════════════════════╡
│ Copyright 2020 Justine Alexandra Roberts Tunney                              │
│                                                                              │
│ Permission to use, copy, modify, and/or distribute this software for         │
│ any purpose with or without fee is hereby granted, provided that the         │
│ above copyright notice and this permission notice appear in all copies.      │
│                                                                              │
│ THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL                │
│ WARRANTIES WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED                │
│ WARRANTIES OF MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE             │
│ AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL         │
│ DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR        │
│ PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER               │
│ TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR             │
│ PERFORMANCE OF THIS SOFTWARE.                                                │
╚─────────────────────────────────────────────────────────────────────────────*/
#include "libc/fmt/bing.internal.h"
#include "libc/mem/gc.h"
#include "libc/testlib/testlib.h"
#include "libc/x/x.h"
#include "tool/viz/lib/halfblit.h"

TEST(halfblit, test_4x4_to_2x2) {
  EXPECT_BINEQ(u" ☺"
               u"►◄",
               halfblit(2, gc(xunbing(u" ☺☻♥"
                                      u"►◄↕‼"
                                      u"♀♪♫☼"
                                      u"∟↔▲▼"))));
}

TEST(halfblit, test_8x8_to_4x4) {
  EXPECT_BINEQ(u" ☺☻♥"
               u"►◄↕‼"
               u"◘○◙♂"
               u"↑↓→←",
               halfblit(4, gc(xunbing(u" ☺☻♥♦♣♠•"
                                      u"►◄↕‼¶§▬↨"
                                      u"◘○◙♂♀♪♫☼"
                                      u"↑↓→←∟↔▲▼"
                                      u"01234567"
                                      u"░▒▓│┤╡╢╖"
                                      u"╕╣║╗╝╜╛┐"
                                      u"89:;<=>?"))));
}
